#[repr(u8)]pub enum Ahbsingle {
Incrburst = 0,
Singleburst = 1,
}Variants
Incrburst = 0
The remaining data in the transfer is sent using INCR burst size.
Singleburst = 1
The remaining data in the transfer is sent using Single burst size.
Implementations